from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Directory, Int, String, Boolean

Ctat_Mutations_V0_1_0 = CommandToolBuilder(tool="ctat_mutations", base_command=["ctat_mutations"], inputs=[ToolInput(tag="in_left", input_type=File(optional=True), prefix="--left", doc=InputDocumentation(doc="Path to one of the two paired RNAseq samples (left)")), ToolInput(tag="in_right", input_type=File(optional=True), prefix="--right", doc=InputDocumentation(doc="Path to one of the two paired RNAseq samples (right)")), ToolInput(tag="in_out_dir", input_type=Directory(optional=True), prefix="--out_dir", doc=InputDocumentation(doc="output directory")), ToolInput(tag="in_reference", input_type=File(optional=True), prefix="--reference", doc=InputDocumentation(doc="Path to the reference genome to use in the analysis\npipeline.")), ToolInput(tag="in_index", input_type=File(optional=True), prefix="--index", doc=InputDocumentation(doc="The initial index is made only from the reference\ngenome and can be shared. If premade, supply a path\nhere to the index directory so that it is not rebuilt\nfor every alignment. Please provide the full path.")), ToolInput(tag="in_dbsnp_vcf", input_type=File(optional=True), prefix="--dbsnp_vcf", doc=InputDocumentation(doc="dbsnp vcf file for the reference genome.")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="--threads", doc=InputDocumentation(doc="The number of threads to use for multi-threaded steps.")), ToolInput(tag="in_variant_filtering_mode", input_type=String(optional=True), prefix="--variant_filtering_mode", doc=InputDocumentation(doc="Specifies the variant filtering method.")), ToolInput(tag="in_variant_call_mode", input_type=String(optional=True), prefix="--variant_call_mode", doc=InputDocumentation(doc="Specifies the variant calling method to use.")), ToolInput(tag="in_ref_bed", input_type=File(optional=True), prefix="--ref_bed", doc=InputDocumentation(doc="BED file\nBed file for reference genome, required only if making\nthe mutation inspector json. If given the json file\nwill be made. Please make sure the bed file is indexed\nand that bed.idx file is in the same folder with the\nsame file basename as the related bed file.")), ToolInput(tag="in_plot", input_type=Boolean(optional=True), prefix="--plot", doc=InputDocumentation(doc="Turns off plotting recalibration of alignments.")), ToolInput(tag="in_cosmic_vcf_gz", input_type=String(optional=True), prefix="--cosmic_vcf_gz", doc=InputDocumentation(doc="Coding Cosmic Mutation VCF annotated with Phenotype\nInformation and zipped using bgzip.")), ToolInput(tag="in_no_filter_rna_editing", input_type=Boolean(optional=True), prefix="--no_filter_rna_editing", doc=InputDocumentation(doc="if enabled, turns off filtering based on known rna-\nediting sites from radar and rediportal")), ToolInput(tag="in_tissue_type", input_type=String(optional=True), prefix="--tissue_type", doc=InputDocumentation(doc="Tissue type (used in CRAVAT variant prioritation).\nSupported classifiers can be found at\nhttp://www.cravat.us/help.jsp)")), ToolInput(tag="in_email", input_type=String(optional=True), prefix="--email", doc=InputDocumentation(doc="Email used to notify of errors associated with cravat.")), ToolInput(tag="in_wdl_compatible_run", input_type=File(optional=True), prefix="--wdl_compatible_run", doc=InputDocumentation(doc="Cromwell/WDL requires execution to happen relative to\nan output directory of dynaically created without\ngiving the directory path to the underlying\ntools/pipelines. This requires a pipeline to use\nrelative paths which can be dangerous outside of\nCromwell/WDL. This will ignore any output directory\nspecified in the command line and force the output to\nbe relative paths. DO NOT USE outside of Cromwell/WDL.")), ToolInput(tag="in_cravat_annotation_header", input_type=File(optional=True), prefix="--cravat_annotation_header", doc=InputDocumentation(doc="Headers for each CRAVAT feature annotated to the VCF\nfile (used in BCFtools).")), ToolInput(tag="in_bam", input_type=File(optional=True), prefix="--bam", doc=InputDocumentation(doc="Sample file in the form of a bam, if this is given NO\nalignment will be performed; the alignment mode\ncommand line will be ignored; let and right sample\nfiles will be ignored. Normal pipeline processing will\npick up directly after alignment in the pipeline with\nthe supplied bam.")), ToolInput(tag="in_alignment_mode", input_type=String(optional=True), prefix="--alignment_mode", doc=InputDocumentation(doc="Specifies the alignment and indexing algorithm to use.")), ToolInput(tag="in_base_depth", input_type=Boolean(optional=True), prefix="--base_depth", doc=InputDocumentation(doc="Calculates the base coverage per base.")), ToolInput(tag="in_star_memory", input_type=String(optional=True), prefix="--star_memory", doc=InputDocumentation(doc="Memory limit for star index. This should be used to\nincrease memory if needed. Reducing memory consumption\nshould be performed with the STAR Limited mod.")), ToolInput(tag="in_debug", input_type=Boolean(optional=True), prefix="--debug", doc=InputDocumentation(doc="sets debug mode for logger")), ToolInput(tag="in_genome_lib_dir", input_type=Directory(optional=True), prefix="--genome_lib_dir", doc=InputDocumentation(doc="genome lib directory - see\nhttp://FusionFilter.github.io for details. Uses env\nvar CTAT_GENOME_LIB as default")), ToolInput(tag="in_skip_cravat", input_type=Boolean(optional=True), prefix="--skip_cravat", doc=InputDocumentation(doc="Skips CRAVAT services.")), ToolInput(tag="in_realign", input_type=Boolean(optional=True), prefix="--realign", doc=InputDocumentation(doc="Turns off optional indel realignment step.")), ToolInput(tag="in_no_recalibrate_bam", input_type=Boolean(optional=True), prefix="--no_recalibrate_bam", doc=InputDocumentation(doc="If used, turns off gatk recalibration of bam files\nbefore samtools variant calling.")), ToolInput(tag="in_sequencing_platform", input_type=Int(optional=True), prefix="--sequencing_platform", doc=InputDocumentation(doc="Platform\nThe sequencing platform used to generate the samples\nchoices include ILLUMINA SLX,SOLEXA SOLID,454 COMPLETE\nPACBIO IONTORRENT CAPILLARY ONT.\n"))], outputs=[ToolOutput(tag="out_out_dir", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_out_dir", type_hint=File()), doc=OutputDocumentation(doc="output directory")), ToolOutput(tag="out_wdl_compatible_run", output_type=File(optional=True), selector=InputSelector(input_to_select="in_wdl_compatible_run", type_hint=File()), doc=OutputDocumentation(doc="Cromwell/WDL requires execution to happen relative to\nan output directory of dynaically created without\ngiving the directory path to the underlying\ntools/pipelines. This requires a pipeline to use\nrelative paths which can be dangerous outside of\nCromwell/WDL. This will ignore any output directory\nspecified in the command line and force the output to\nbe relative paths. DO NOT USE outside of Cromwell/WDL."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Ctat_Mutations_V0_1_0().translate("wdl", allow_empty_container=True)

